@@ -1,6 +1,8 @@
 package Elive::Entity::Role;
 use warnings; use strict;
+
 use Mouse;
+use Mouse::Util::TypeConstraints;
 
 use Elive::Struct;
 use base qw{Elive::Struct};
@@ -20,4 +22,7 @@ __PACKAGE__->entity_name('Role');
 has 'roleId' => (is => 'rw', isa => 'Int', required => 1);
 __PACKAGE__->primary_key('roleId');
 
+coerce 'Elive::Entity::Role' => from 'HashRef'
+          => via {Elive::Entity::Role->new($_) };
+
 1;
